==> nodegit-0.2.4.tgz: package/src/status_list.cc <==
// This is a generated file, modify: generate/templates/class_content.cc.
#include <nan.h>
#include <string.h>

extern "C" {
  #include <git2.h>
 }


#include "../include/functions/copy.h"
#include "../include/macros.h"
#include "../include/status_list.h"

 
#include <iostream>

using namespace std;
using namespace v8;
using namespace node;

  GitStatusList::GitStatusList(git_status_list *raw, bool selfFreeing) {
    this->raw = raw;
    this->selfFreeing = selfFreeing;
  }

  GitStatusList::~GitStatusList() {
   }

  void GitStatusList::InitializeComponent(Handle<v8::Object> target) {
    NanScope();

    Local<FunctionTemplate> tpl = NanNew<FunctionTemplate>(New);

    tpl->InstanceTemplate()->SetInternalFieldCount(1);
    tpl->SetClassName(NanNew<String>("StatusList"));

  
    Local<Function> _constructor_template = tpl->GetFunction();
    NanAssignPersistent(constructor_template, _constructor_template);
    target->Set(NanNew<String>("StatusList"), _constructor_template);
  }

  NAN_METHOD(GitStatusList::New) {
    NanScope();

    if (args.Length() == 0 || !args[0]->IsExternal()) {
         return NanThrowError("A new GitStatusList cannot be instantiated.");
     }

    GitStatusList* object = new GitStatusList(static_cast<git_status_list *>(Handle<External>::Cast(args[0])->Value()), args[1]->BooleanValue());
    object->Wrap(args.This());

    NanReturnValue(args.This());
  }

  Handle<Value> GitStatusList::New(void *raw, bool selfFreeing) {
    NanEscapableScope();
    Handle<Value> argv[2] = { NanNew<External>((void *)raw), NanNew<Boolean>(selfFreeing) };
    return NanEscapeScope(NanNew<Function>(GitStatusList::constructor_template)->NewInstance(2, argv));
  }

  git_status_list *GitStatusList::GetValue() {
    return this->raw;
  }

  git_status_list **GitStatusList::GetRefValue() {
    return &this->raw;
  }

     Persistent<Function> GitStatusList::constructor_template;

==> nodegit-0.2.5.tgz: package/src/status_list.cc <==
// This is a generated file, modify: generate/templates/class_content.cc.
#include <nan.h>
#include <string.h>

extern "C" {
  #include <git2.h>
 }


#include "../include/functions/copy.h"
#include "../include/macros.h"
#include "../include/status_list.h"

 
#include <iostream>

using namespace std;
using namespace v8;
using namespace node;

  GitStatusList::GitStatusList(git_status_list *raw, bool selfFreeing) {
    this->raw = raw;
    this->selfFreeing = selfFreeing;
  }

  GitStatusList::~GitStatusList() {
   }

  void GitStatusList::InitializeComponent(Handle<v8::Object> target) {
    NanScope();

    Local<FunctionTemplate> tpl = NanNew<FunctionTemplate>(JSNewFunction);

    tpl->InstanceTemplate()->SetInternalFieldCount(1);
    tpl->SetClassName(NanNew<String>("StatusList"));

  
    Local<Function> _constructor_template = tpl->GetFunction();
    NanAssignPersistent(constructor_template, _constructor_template);
    target->Set(NanNew<String>("StatusList"), _constructor_template);
  }

  NAN_METHOD(GitStatusList::JSNewFunction) {
    NanScope();

    if (args.Length() == 0 || !args[0]->IsExternal()) {
         return NanThrowError("A new GitStatusList cannot be instantiated.");
     }

    GitStatusList* object = new GitStatusList(static_cast<git_status_list *>(Handle<External>::Cast(args[0])->Value()), args[1]->BooleanValue());
    object->Wrap(args.This());

    NanReturnValue(args.This());
  }

  Handle<Value> GitStatusList::New(void *raw, bool selfFreeing) {
    NanEscapableScope();
    Handle<Value> argv[2] = { NanNew<External>((void *)raw), NanNew<Boolean>(selfFreeing) };
    return NanEscapeScope(NanNew<Function>(GitStatusList::constructor_template)->NewInstance(2, argv));
  }

  git_status_list *GitStatusList::GetValue() {
    return this->raw;
  }

  git_status_list **GitStatusList::GetRefValue() {
    return &this->raw;
  }

     Persistent<Function> GitStatusList::constructor_template;
